#include <math.h>
#include "drone.h"
#include "global.h"
#include "music_player.h"

int Drone::max_light_counter = 100;

Drone::Drone() : Object() {
	sprite_index = 0;
	radius = 32;
}


Drone::~Drone() {
}

void Drone::Init() {
	Object::Init();
	light_counter = rand() % max_light_counter;
	speed = 1;
	angle = rand()%256 * 2*M_PI/256.0;
}


void Drone::Update() {
	//Object::Update();

	++light_counter;
	light_counter %= max_light_counter;

	float vx = speed * cos(angle);
	float vy = speed * sin(angle);

	angle += 0.01;
	speed += 0.001;
	speed = MIN(speed, 4);

	float old_x = pos.x;
	float old_y = pos.y;

	pos.x += vx;
	pos.y += vy;

	if (pos.x < min.x || pos.x > max.x || pos.y > max.y || pos.y < min.y) {
		pos.x = old_x;
		pos.y = old_y;
		angle += M_PI;
		play_sound(cling_sample, 255, 128, -100, 0);
	}

	while (angle > 2*M_PI) {
		angle -= 2*M_PI;
	}
}


void Drone::Draw(BITMAP *canvas) {
	BITMAP *spr = 0;
	int sprite_index = this->sprite_index;

	if (light_counter > max_light_counter/2) {
		++sprite_index;
	}

	spr = drone_sprite[sprite_index];

	pivot_sprite(canvas, spr, (int)pos.x, (int)pos.y, spr->w/2, spr->h/2, dir);
}
