#include <math.h>
#include "explosion.h"
#include <MASkinG.h>



EXPLOSION *create_explosion(BITMAP *bmp, int ix, int iy) {
	int x,y,i;

	EXPLOSION *e = (EXPLOSION *)malloc(sizeof(EXPLOSION));

	e->particle_count = bmp->w * bmp->h;
	e->particles = (PARTICLE *)malloc(e->particle_count * sizeof(PARTICLE));

	int pink = makecol(255, 0, 255);

	i = 0;
	for (y=0; y<bmp->h; y++) {
		for (x=0; x<bmp->w; x++) {
			e->particles[i].x = ix+x;
			e->particles[i].y = iy+y;
			e->particles[i].dir = rand()%256;
			e->particles[i].v = 1.5*((rand()%100)/100.0+0.5);
			e->particles[i].a = 0.99;
			int col = getpixel(bmp, x, y);
			if (col != pink) {
				e->particles[i].col = col;
			}
			else {
				e->particles[i].col = makecol(rand()%32+224, rand()%128+64, 0);
			}
			e->particles[i].life = (int)(MAS::Settings::logicFrameRate*1.0);
			++i;
		}
	}

	return e;
}


void destroy_explosion(EXPLOSION *e) {
	free(e->particles);
}


int update_explosion(EXPLOSION *e) {
	int done = 1;
	int i;
	int dir;

	for (i=0; i<e->particle_count; i++) {
		if (e->particles[i].life > 0) {
			dir = (int)(e->particles[i].dir);
			e->particles[i].x += e->particles[i].v*SIN[dir];
			e->particles[i].y -= e->particles[i].v*COS[dir];
			e->particles[i].v *= e->particles[i].a;
			e->particles[i].life -= 1;

			done = 0;
		}
	}

	return done;
}


void draw_explosion(EXPLOSION *e, BITMAP *canvas) {
	int i;
	int x;
	int y;

	for (i=0; i<e->particle_count; i++) {
		if (e->particles[i].life > 0) {
			x = (int)e->particles[i].x;
			y = (int)e->particles[i].y;
			putpixel(canvas, x, y, e->particles[i].col);
		}
	}
}
