#include "gamedialog.h"


MainGameDialog::MainGameDialog() : GameDialog() {
	desktop.Shape(0, 0, SCREEN_W, SCREEN_H);
	desktop.timePanel = &timePanel;
	Add(desktop);

	timePanel.Shape(484, 376, 168, 96);
	Add(timePanel);

	hscPanel = new HscDialog;
	helpPanel = new HelpDialog;

	acc.Add(KEY_F1, 0, 2000);
	Add(acc);

	Add(anim);
	escapeExits = false;
}

MainGameDialog::~MainGameDialog() {
DEBUG
	delete hscPanel;
DEBUG
	delete helpPanel;
DEBUG
}

int MainGameDialog::Run() {
	// run the dialog and remember which object caused it to close
	desktop.StartPlaying();
	hscPanel->Shape(484+160, 8, 160, 356);
	helpPanel->Shape(484+160, 8, 160, 356);
	Add(*hscPanel);
	Add(*helpPanel);
	progress = 0;
	duration = 30;
	state = 5;
	//Settings::showMouse = false;
	Execute(&desktop);
	//Settings::showMouse = true;
	Remove(*hscPanel);
	Remove(*helpPanel);
	return S_MAIN_MENU;
}


void MainGameDialog::HandleEvent(Widget &obj, int msg, int arg1, int arg2) {
	GameDialog::HandleEvent(obj, msg, arg1, arg2);

	if (msg == 2000) {
		switch (state) {
			case 0:
				state = 1;
				progress = 0;
			break;

			case 3:
				state = 4;
				progress = 0;
			break;
		};
	}
	else if (msg == 2001) {
DEBUG
		hscPanel->FillHscList();
DEBUG
	}
}


void MainGameDialog::MsgTick() {
	GameDialog::MsgTick();

	switch (state) {
		case 1: {
			++progress;
			hscPanel->x(484 + progress*160/duration);
			if (progress == duration) {
				state = 2;
				progress = 0;
			}
		}
		break;

		case 2: {
			++progress;
			helpPanel->x(484 + (duration - progress)*160/duration);
			if (progress == duration) {
				state = 3;
				progress = 0;
			}
		}
		break;

		case 4: {
			++progress;
			helpPanel->x(484 + progress*160/duration);
			if (progress == duration) {
				state = 5;
				progress = 0;
			}
		}
		break;

		case 5: {
			++progress;
			hscPanel->x(484 + (duration - progress)*160/duration);
			if (progress == duration) {
				state = 0;
				progress = 0;
			}
		}
		break;
	};
}


void MainGameDialog::HscDialog::MsgInitSkin() {
	Dialog::MsgInitSkin();

	for (int i=0; i<4; i++) {
		lstHsc.SetFont(1, i);
		lstHsc.SetFontColor(Color(0,192,0), Color::black, i);
		lstHsc.GetHeader()->SetFont(1, i);
		lstHsc.GetHeader()->SetFontColor(Color(0,192,0), Color::black, i);
		lblF1.SetFont(1, i);
		lblF1.SetFontColor(Color(224,224,224), -1, i);
	}
}


MainGameDialog::HscDialog::HscDialog() : Dialog() {
	panel.Shape(0, 0, 168, 240);
	Add(panel);

	lblF1.ClearFlag(D_AUTOSIZE);
	lblF1.Setup(8, 12, 144, 13, 0, 0, "Press F1 for help", 2);
	Add(lblF1);

	lstHsc.Shape(8, 32, 144, 197);
	lstHsc.SetHeader(&hscHeader);
	lstHsc.InsertColumn("Name", 0, 2);
	lstHsc.InsertColumn("Score", 1, 2);
	lstHsc.SetColumnWidth(0, 64);
	lstHsc.SetColumnWidth(1, 76);
	lstHsc.EnableColumnResizing(false);
	lstHsc.SetHeaderVisibility(false);
	lstHsc.Disable();
	FillHscList();

	Add(lstHsc);
}


MainGameDialog::HscDialog::~HscDialog() {
	lstHsc.SetHeader(0);
}


void MainGameDialog::HscDialog::FillHscList() {
DEBUG
	lstHsc.DeleteAllItems();
DEBUG
	for (int i=0; i<hsc->Count() && i<15; i++) {
DEBUG
		lstHsc.InsertItem(new HscItem(i%2));

		HSC::Entry e = hsc->GetEntry(i);
		static char buf[16];

		usprintf(buf, "%d", i+1);
		lstHsc.SetItem(i, 0, e.name.c_str());
		int min = e.score/(60*100);
		int sec = e.score/100 - min*60;
		int msec = e.score - sec*100 - min*60*100;
		usprintf(buf, "%01d:%02d.%02d", min, sec, msec);
DEBUG
		lstHsc.SetItem(i, 1, buf);
DEBUG
	}
DEBUG
}




void MainGameDialog::HelpDialog::MsgInitSkin() {
	Dialog::MsgInitSkin();

	for (int i=0; i<4; i++) {
		lblHelp.SetFont(1, i);
		lblHelp.SetFontColor(Color(0,192,0), Color::black, i);
		lblF1.SetFont(1, i);
		lblF1.SetFontColor(Color(224,224,224), -1, i);
	}
}


MainGameDialog::HelpDialog::HelpDialog() : Dialog() {
	panel.Shape(0, 0, 168, 240);
	Add(panel);

	lblF1.ClearFlag(D_AUTOSIZE);
	lblF1.Setup(8, 12, 144, 13, 0, 0, "Press F1 for highscores", 2);
	Add(lblF1);

	pnlHelp.Shape(8, 32, 144, 197);
	Add(pnlHelp);

	lblHelp.ClearFlag(D_AUTOSIZE);
	lblHelp.Shape(12, 36, 136, 188);
	lblHelp.SetWordWrap(true);
	lblHelp.SetText("Grab your ship with the mouse and move it around the playfield. Avoid hitting the walls, enemy drones and rockets. The game starts as soon as you move your ship. Try to keep your ship in one piece for the longest time possible. If you can last 20 seconds, you're a master!");
	Add(lblHelp);
}
